@@ -64,7 +64,9 @@ NNS.ARMA.optim <- function(variable, training.set,
                         print.trace = TRUE,
                         ncores = NULL){
 
-  if(any(class(variable)=="tbl")) variable <- as.vector(unlist(variable))
+  if(any(class(variable)==c("tbl", "data.table"))) variable <- as.vector(unlist(variable))
+
+  if(sum(is.na(variable)) > 0) stop("You have some missing values, please address.")
 
   if(length(training.set)==length(variable)){ stop("Please provide a 'training.set' value (integer) less than the length of the variable.")}
 
