@@ -421,14 +421,15 @@ NNS.reg = function (x, y,
   if(is.null(x.label)) x.label <- "x"
 
 
-  dependence <- tryCatch(NNS.dep(x, y, print.map = FALSE, asym = TRUE)$Dependence, error = function(e) 0)
+  dependence <- tryCatch(NNS.dep(x, y, print.map = FALSE, asym = TRUE)$Dependence, error = function(e) NNS.copula(cbind(x,y)))
   dependence <- (dependence^2 + dependence^(.5))/2
 
   dep.reduced.order <- max(1, ifelse(multivariate.call,
                                      ceiling(max(1, (dependence * 10))) + 1,
                                      floor(dependence*10)))
 
-  if(!multivariate.call) {if(!is.null(order)) dep.reduced.order <- order} else stn <- 0
+  if(multivariate.call) stn <- 0
+  if(!is.null(order)) dep.reduced.order <- order
 
   if(dependence > stn){
     if(dependence == 1 || dep.reduced.order == "max"){
