@@ -18,8 +18,10 @@
 
 NNS.FSD.uni <- function(x, y, type = "discrete"){
 
-    if(any(class(x)=="tbl")) x <- as.vector(unlist(x))
-    if(any(class(y)=="tbl")) y <- as.vector(unlist(y))
+    if(any(class(x)==c("tbl", "data.table"))) x <- as.vector(unlist(x))
+    if(any(class(y)==c("tbl", "data.table"))) y <- as.vector(unlist(y))
+
+    if(sum(is.na(cbind(x,y))) > 0) stop("You have some missing values, please address.")
 
     type <- tolower(type)
 
@@ -73,8 +75,10 @@ NNS.FSD.uni <- function(x, y, type = "discrete"){
 
 NNS.SSD.uni <- function(x, y){
 
-    if(any(class(x)=="tbl")) x <- as.vector(unlist(x))
-    if(any(class(y)=="tbl")) y <- as.vector(unlist(y))
+    if(any(class(x)==c("tbl", "data.table"))) x <- as.vector(unlist(x))
+    if(any(class(y)==c("tbl", "data.table"))) y <- as.vector(unlist(y))
+
+    if(sum(is.na(cbind(x,y))) > 0) stop("You have some missing values, please address.")
 
     if(min(y) > min(x) | mean(y) > mean(x)) {
         return(0)
@@ -115,8 +119,10 @@ NNS.SSD.uni <- function(x, y){
 
 NNS.TSD.uni <- function(x, y){
 
-    if(any(class(x)=="tbl")) x <- as.vector(unlist(x))
-    if(any(class(y)=="tbl")) y <- as.vector(unlist(y))
+    if(any(class(x)==c("tbl", "data.table"))) x <- as.vector(unlist(x))
+    if(any(class(y)==c("tbl", "data.table"))) y <- as.vector(unlist(y))
+
+    if(sum(is.na(cbind(x,y))) > 0) stop("You have some missing values, please address.")
 
     if(min(y) > min(x) | mean(y) > mean(x)) {
         return(0)
